api

package
v1.5.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 22, 2026 License: MPL-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package api is a generated GoMock package.

Package api is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockClient

type MockClient struct {
	// contains filtered or unexported fields
}

MockClient is a mock of Client interface.

func NewMockClient

func NewMockClient(ctrl *gomock.Controller) *MockClient

NewMockClient creates a new mock instance.

func (*MockClient) Authorize

func (m *MockClient) Authorize(ctx context.Context, callback func(error)) (*api.AuthorizeResponse, error)

Authorize mocks base method.

func (*MockClient) AwaitMeasurement

func (m *MockClient) AwaitMeasurement(ctx context.Context, id string) (*globalping.Measurement, error)

AwaitMeasurement mocks base method.

func (*MockClient) Close

func (m *MockClient) Close()

Close mocks base method.

func (*MockClient) CreateMeasurement

CreateMeasurement mocks base method.

func (*MockClient) EXPECT

func (m *MockClient) EXPECT() *MockClientMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockClient) GetMeasurement

func (m *MockClient) GetMeasurement(ctx context.Context, id string) (*globalping.Measurement, error)

GetMeasurement mocks base method.

func (*MockClient) GetMeasurementRaw

func (m *MockClient) GetMeasurementRaw(ctx context.Context, id string) ([]byte, error)

GetMeasurementRaw mocks base method.

func (*MockClient) Limits

Limits mocks base method.

func (*MockClient) Logout

func (m *MockClient) Logout(ctx context.Context) error

Logout mocks base method.

func (*MockClient) RevokeToken

func (m *MockClient) RevokeToken(ctx context.Context, token string) error

RevokeToken mocks base method.

func (*MockClient) TokenIntrospection

func (m *MockClient) TokenIntrospection(ctx context.Context, token string) (*api.IntrospectionResponse, error)

TokenIntrospection mocks base method.

type MockClientMockRecorder

type MockClientMockRecorder struct {
	// contains filtered or unexported fields
}

MockClientMockRecorder is the mock recorder for MockClient.

func (*MockClientMockRecorder) Authorize

func (mr *MockClientMockRecorder) Authorize(ctx, callback any) *gomock.Call

Authorize indicates an expected call of Authorize.

func (*MockClientMockRecorder) AwaitMeasurement

func (mr *MockClientMockRecorder) AwaitMeasurement(ctx, id any) *gomock.Call

AwaitMeasurement indicates an expected call of AwaitMeasurement.

func (*MockClientMockRecorder) Close

func (mr *MockClientMockRecorder) Close() *gomock.Call

Close indicates an expected call of Close.

func (*MockClientMockRecorder) CreateMeasurement

func (mr *MockClientMockRecorder) CreateMeasurement(ctx, measurement any) *gomock.Call

CreateMeasurement indicates an expected call of CreateMeasurement.

func (*MockClientMockRecorder) GetMeasurement

func (mr *MockClientMockRecorder) GetMeasurement(ctx, id any) *gomock.Call

GetMeasurement indicates an expected call of GetMeasurement.

func (*MockClientMockRecorder) GetMeasurementRaw

func (mr *MockClientMockRecorder) GetMeasurementRaw(ctx, id any) *gomock.Call

GetMeasurementRaw indicates an expected call of GetMeasurementRaw.

func (*MockClientMockRecorder) Limits

func (mr *MockClientMockRecorder) Limits(ctx any) *gomock.Call

Limits indicates an expected call of Limits.

func (*MockClientMockRecorder) Logout

func (mr *MockClientMockRecorder) Logout(ctx any) *gomock.Call

Logout indicates an expected call of Logout.

func (*MockClientMockRecorder) RevokeToken

func (mr *MockClientMockRecorder) RevokeToken(ctx, token any) *gomock.Call

RevokeToken indicates an expected call of RevokeToken.

func (*MockClientMockRecorder) TokenIntrospection

func (mr *MockClientMockRecorder) TokenIntrospection(ctx, token any) *gomock.Call

TokenIntrospection indicates an expected call of TokenIntrospection.

type MockProbe

type MockProbe struct {
	// contains filtered or unexported fields
}

MockProbe is a mock of Probe interface.

func NewMockProbe

func NewMockProbe(ctrl *gomock.Controller) *MockProbe

NewMockProbe creates a new mock instance.

func (*MockProbe) DetectContainerEngine

func (m *MockProbe) DetectContainerEngine() (probe.ContainerEngine, error)

DetectContainerEngine mocks base method.

func (*MockProbe) EXPECT

func (m *MockProbe) EXPECT() *MockProbeMockRecorder

EXPECT returns an object that allows the caller to indicate expected use.

func (*MockProbe) InspectContainer

func (m *MockProbe) InspectContainer(containerEngine probe.ContainerEngine) error

InspectContainer mocks base method.

func (*MockProbe) RunContainer

func (m *MockProbe) RunContainer(containerEngine probe.ContainerEngine) error

RunContainer mocks base method.

type MockProbeMockRecorder

type MockProbeMockRecorder struct {
	// contains filtered or unexported fields
}

MockProbeMockRecorder is the mock recorder for MockProbe.

func (*MockProbeMockRecorder) DetectContainerEngine

func (mr *MockProbeMockRecorder) DetectContainerEngine() *gomock.Call

DetectContainerEngine indicates an expected call of DetectContainerEngine.

func (*MockProbeMockRecorder) InspectContainer

func (mr *MockProbeMockRecorder) InspectContainer(containerEngine any) *gomock.Call

InspectContainer indicates an expected call of InspectContainer.

func (*MockProbeMockRecorder) RunContainer

func (mr *MockProbeMockRecorder) RunContainer(containerEngine any) *gomock.Call

RunContainer indicates an expected call of RunContainer.

Jump to